import datetime
from _typeshed import Incomplete
from datetime import tzinfo

from pytz import UTC as UTC

class FixedOffset(tzinfo):
    def __init__(self, offset, name) -> None: ...
    def utcoffset(self, dt): ...
    def tzname(self, dt): ...
    def dst(self, dt): ...

STDOFFSET: datetime.timedelta
DSTOFFSET: datetime.timedelta

class LocalTimezone(tzinfo):
    def utcoffset(self, dt): ...
    def dst(self, dt): ...
    def tzname(self, dt): ...

class USTimeZone(tzinfo):
    stdoffset: Incomplete
    reprname: Incomplete
    stdname: Incomplete
    dstname: Incomplete
    def __init__(self, hours, reprname, stdname, dstname) -> None: ...
    def tzname(self, dt): ...
    def utcoffset(self, dt): ...
    def dst(self, dt): ...

Eastern: USTimeZone
Central: USTimeZone
Mountain: USTimeZone
Pacific: USTimeZone
